@@ -114,7 +114,7 @@ class Siwave:
                 # but doesn't return the wrapper of oApp
                 print("Launching Siwave with module win32com.")
 
-                self._main.oSiwave = win32com.client.Dispatch("Siwave.Application.2021.2")
+                self._main.oSiwave = win32com.client.Dispatch(version)
 
             self._main.AEDTVersion = version_key
             self.oSiwave = self._main.oSiwave
